@@ -117,12 +117,15 @@ extern "C" SEXP RAdbcAllocateDriver(void) {
 }
 
 extern "C" SEXP RAdbcLoadDriver(SEXP driver_name_sexp, SEXP entrypoint_sexp,
-                                SEXP version_sexp, SEXP load_flags_sexp, SEXP driver_sexp,
+                                SEXP version_sexp, SEXP load_flags_sexp,
+                                SEXP additional_search_path_list_sexp, SEXP driver_sexp,
                                 SEXP error_sexp) {
   const char* driver_name = adbc_as_const_char(driver_name_sexp);
   const char* entrypoint = adbc_as_const_char(entrypoint_sexp, /*nullable*/ true);
   int version = adbc_as_int(version_sexp);
   int load_flags = adbc_as_int(load_flags_sexp);
+  const char* additional_search_path_list =
+      adbc_as_const_char(additional_search_path_list_sexp, /*nullable*/ true);
 
   if (TYPEOF(driver_sexp) != EXTPTRSXP) {
     Rf_error("driver must be an externalptr");
@@ -138,8 +141,8 @@ extern "C" SEXP RAdbcLoadDriver(SEXP driver_name_sexp, SEXP entrypoint_sexp,
     Rf_error("error must be an externalptr");
   }
 
-  int status =
-      AdbcFindLoadDriver(driver_name, entrypoint, version, load_flags, driver, error);
+  int status = AdbcFindLoadDriver(driver_name, entrypoint, version, load_flags,
+                                  additional_search_path_list, driver, error);
   return Rf_ScalarInteger(status);
 }
 
